==> 2.4.zip: piwigo/language/cs_CZ/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// | Czech language localization                                           |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2009     Pavel Budka & Petr Jirsa    http://pbudka.co.cc |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'Aktualizace';
$lang['Upgrade from version %s to %s'] = 'Aktualizace z verze %s na %s';
$lang['Statistics'] = 'Statistika';
$lang['total upgrade time'] = 'celkový čas aktualizace';
$lang['total SQL time'] = 'celkový čas SQL';
$lang['SQL queries'] = 'SQL dotazy';
$lang['Upgrade informations'] = 'Informace o aktualizaci';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Proveďte kontrolu údržby v [Administrace>Nástroje>Údržba] pokud dojde k problému.';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Jen administrátor smí spustit aktualizaci: prosím přihlašte se níže.';
$lang['You do not have access rights to run upgrade'] = 'nemáte přístupová práva na spuštění upgrade';

// Upgrade informations from upgrade_1.3.1.php
$lang['All sub-albums of private albums become private'] = 'Všechny sub-alba privátních alb zůstanou privatní';
$lang['User permissions and group permissions have been erased'] = 'Uživatelská oprávnění a oprávnění skupin byla vymazána';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Z předchozí konfigurace byly zachovány pouze předpony náhledů a email adresa správce.';

// missing translations 2.1.0
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Navrhujeme aktualizovat databázi Vaší galerie Piwigo ze starší na novou verzi.
Asistent aktualizace se domnívá, že aktuálně používáte <strong>verzi %s</strong> (nebo odpovídající).';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Jako předběžné opatření byly deaktivovány následující doplňky. Prosím zkontrolujte aktualizace těchto doplňků předtím než je znovu aktivujete:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'V <i>%s</i>, před <b>?></b>, vložením:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Jako preventivní opatření, byli náseldující šablony deaktivovány. Musíte zkontrolovat nejprve jestli není nová verze předtím než je reaktivujete:';
?>

==> 14.5.0.zip: piwigo/language/cs_CZ/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = 'Aktualizace';
$lang['Upgrade from version %s to %s'] = 'Aktualizace z verze %s na %s';
$lang['Statistics'] = 'Statistika';
$lang['total upgrade time'] = 'celkový čas aktualizace';
$lang['total SQL time'] = 'celkový čas SQL';
$lang['SQL queries'] = 'SQL dotazy';
$lang['Upgrade informations'] = 'Informace o aktualizaci';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Proveďte kontrolu údržby v [Administrace>Nástroje>Údržba] pokud dojde k problému.';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Jen administrátor smí spustit aktualizaci: prosím přihlašte se níže.';
$lang['You do not have access rights to run upgrade'] = 'nemáte přístupová práva na spuštění upgrade';

// Upgrade informations from upgrade_1.3.1.php
$lang['All sub-albums of private albums become private'] = 'Všechny sub-alba privátních alb zůstanou privatní';
$lang['User permissions and group permissions have been erased'] = 'Uživatelská oprávnění a oprávnění skupin byla vymazána';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Z předchozí konfigurace byly zachovány pouze předpony náhledů a email adresa správce.';

// missing translations 2.1.0
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Navrhujeme aktualizovat databázi Vaší galerie Piwigo ze starší na novou verzi.
Asistent aktualizace se domnívá, že aktuálně používáte <strong>verzi %s</strong> (nebo odpovídající).';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Jako předběžné opatření byly deaktivovány následující doplňky. Prosím zkontrolujte aktualizace těchto doplňků předtím než je znovu aktivujete:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'V <i>%s</i>, před <b>?></b>, vložením:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Jako preventivní opatření, byli náseldující šablony deaktivovány. Musíte zkontrolovat nejprve jestli není nová verze předtím než je reaktivujete:';
$lang['Discover what\'s new in Piwigo %s'] = 'Objevte co je nového v Piwigo %s';
